@@ -121,6 +121,10 @@ class LogLine(object):
                     self._duration = int((split_tokens[-1][:-2]).replace(',',''))
                 except ValueError:
                     self._duration = None
+            elif "flushing" in self.line_str:
+                matchobj = re.search(r'flushing mmaps took (\d+)ms', self.line_str)
+                if matchobj:
+                    self._duration = int(matchobj.group(1))
 
         return self._duration
 
